@@ -8,12 +8,12 @@ import logging
 from typing import TypedDict
 
 PACKAGE_NAME = "zwave-js-server-python"
-__version__ = "0.59.0"
+__version__ = "0.66.0"
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 39
+MIN_SERVER_SCHEMA_VERSION = 41
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 39
+MAX_SERVER_SCHEMA_VERSION = 43
 
 VALUE_UNKNOWN = "unknown"
 
@@ -320,7 +320,7 @@ class InclusionState(IntEnum):
 class RFRegion(IntEnum):
     """Enum for all known RF regions."""
 
-    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/serialapi/misc/SerialAPISetupMessages.ts#L41
+    # https://github.com/zwave-js/node-zwave-js/blob/master/packages/core/src/definitions/RFRegion.ts#L1
     EUROPE = 0
     USA = 1
     AUSTRALIA_AND_NEW_ZEALAND = 2
@@ -330,6 +330,7 @@ class RFRegion(IntEnum):
     RUSSIA = 7
     CHINA = 8
     USA_LONG_RANGE = 9
+    EUROPE_LONG_RANGE = 11
     JAPAN = 32
     KOREA = 33
     UNKNOWN = 254
